@@ -56,20 +56,20 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsNeverCalled(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->never())
-             ->method('doSomething');
+            ->method('doSomething');
     }
 
     public function testMockedMethodIsNeverCalledWithParameter(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->never())
-             ->method('doSomething')
-             ->with('someArg');
+            ->method('doSomething')
+            ->with('someArg');
     }
 
     /**
@@ -78,10 +78,10 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsNotCalledWhenExpectsAnyWithParameter(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomethingElse')
-             ->with('someArg');
+            ->with('someArg');
     }
 
     /**
@@ -90,19 +90,19 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsNotCalledWhenMethodSpecifiedDirectlyWithParameter(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomethingElse')
-             ->with('someArg');
+            ->with('someArg');
     }
 
     public function testMockedMethodIsCalledAtLeastOnce(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->atLeastOnce())
-             ->method('doSomething');
+            ->method('doSomething');
 
         $mock->doSomething();
     }
@@ -110,10 +110,10 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsCalledAtLeastOnce2(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->atLeastOnce())
-             ->method('doSomething');
+            ->method('doSomething');
 
         $mock->doSomething();
         $mock->doSomething();
@@ -122,10 +122,10 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsCalledAtLeastTwice(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->atLeast(2))
-             ->method('doSomething');
+            ->method('doSomething');
 
         $mock->doSomething();
         $mock->doSomething();
@@ -134,10 +134,10 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsCalledAtLeastTwice2(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->atLeast(2))
-             ->method('doSomething');
+            ->method('doSomething');
 
         $mock->doSomething();
         $mock->doSomething();
@@ -147,10 +147,10 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsCalledAtMostTwice(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->atMost(2))
-             ->method('doSomething');
+            ->method('doSomething');
 
         $mock->doSomething();
         $mock->doSomething();
@@ -159,10 +159,10 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsCalledAtMosttTwice2(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->atMost(2))
-             ->method('doSomething');
+            ->method('doSomething');
 
         $mock->doSomething();
     }
@@ -170,10 +170,10 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsCalledOnce(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('doSomething');
+            ->method('doSomething');
 
         $mock->doSomething();
     }
@@ -181,11 +181,11 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsCalledOnceWithParameter(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('doSomethingElse')
-             ->with($this->equalTo('something'));
+            ->method('doSomethingElse')
+            ->with($this->equalTo('something'));
 
         $mock->doSomethingElse('something');
     }
@@ -193,10 +193,10 @@ final class MockObjectTest extends TestCase
     public function testMockedMethodIsCalledExactly(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->exactly(2))
-             ->method('doSomething');
+            ->method('doSomething');
 
         $mock->doSomething();
         $mock->doSomething();
@@ -205,10 +205,10 @@ final class MockObjectTest extends TestCase
     public function testStubbedException(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->will($this->throwException(new Exception));
+            ->will($this->throwException(new Exception));
 
         $this->expectException(Exception::class);
 
@@ -218,10 +218,10 @@ final class MockObjectTest extends TestCase
     public function testStubbedWillThrowException(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->willThrowException(new Exception);
+            ->willThrowException(new Exception);
 
         $this->expectException(Exception::class);
 
@@ -231,18 +231,18 @@ final class MockObjectTest extends TestCase
     public function testStubbedReturnValue(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->will($this->returnValue('something'));
+            ->will($this->returnValue('something'));
 
         $this->assertEquals('something', $mock->doSomething());
 
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->willReturn('something');
+            ->willReturn('something');
 
         $this->assertEquals('something', $mock->doSomething());
     }
@@ -255,20 +255,20 @@ final class MockObjectTest extends TestCase
         ];
 
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->will($this->returnValueMap($map));
+            ->will($this->returnValueMap($map));
 
         $this->assertEquals('d', $mock->doSomething('a', 'b', 'c'));
         $this->assertEquals('h', $mock->doSomething('e', 'f', 'g'));
         $this->assertNull($mock->doSomething('foo', 'bar'));
 
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->willReturnMap($map);
+            ->willReturnMap($map);
 
         $this->assertEquals('d', $mock->doSomething('a', 'b', 'c'));
         $this->assertEquals('h', $mock->doSomething('e', 'f', 'g'));
@@ -278,18 +278,18 @@ final class MockObjectTest extends TestCase
     public function testStubbedReturnArgument(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->will($this->returnArgument(1));
+            ->will($this->returnArgument(1));
 
         $this->assertEquals('b', $mock->doSomething('a', 'b'));
 
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->willReturnArgument(1);
+            ->willReturnArgument(1);
 
         $this->assertEquals('b', $mock->doSomething('a', 'b'));
     }
@@ -297,28 +297,28 @@ final class MockObjectTest extends TestCase
     public function testFunctionCallback(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->onlyMethods(['doSomething'])
-                     ->getMock();
+            ->onlyMethods(['doSomething'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('doSomething')
-             ->will($this->returnCallback(sprintf(
-                 '%s::functionCallback',
-                 FunctionCallbackWrapper::class
-             )));
+            ->method('doSomething')
+            ->will($this->returnCallback(sprintf(
+                '%s::functionCallback',
+                FunctionCallbackWrapper::class,
+            )));
 
         $this->assertEquals('pass', $mock->doSomething('foo', 'bar'));
 
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->onlyMethods(['doSomething'])
-                     ->getMock();
+            ->onlyMethods(['doSomething'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('doSomething')
-             ->willReturnCallback(sprintf(
-                 '%s::functionCallback',
-                 FunctionCallbackWrapper::class
-             ));
+            ->method('doSomething')
+            ->willReturnCallback(sprintf(
+                '%s::functionCallback',
+                FunctionCallbackWrapper::class,
+            ));
 
         $this->assertEquals('pass', $mock->doSomething('foo', 'bar'));
     }
@@ -326,18 +326,18 @@ final class MockObjectTest extends TestCase
     public function testStubbedReturnSelf(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->will($this->returnSelf());
+            ->will($this->returnSelf());
 
         $this->assertEquals($mock, $mock->doSomething());
 
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->willReturnSelf();
+            ->willReturnSelf();
 
         $this->assertEquals($mock, $mock->doSomething());
     }
@@ -345,20 +345,20 @@ final class MockObjectTest extends TestCase
     public function testStubbedReturnOnConsecutiveCalls(): void
     {
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->will($this->onConsecutiveCalls('a', 'b', 'c'));
+            ->will($this->onConsecutiveCalls('a', 'b', 'c'));
 
         $this->assertEquals('a', $mock->doSomething());
         $this->assertEquals('b', $mock->doSomething());
         $this->assertEquals('c', $mock->doSomething());
 
         $mock = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->method('doSomething')
-             ->willReturnOnConsecutiveCalls('a', 'b', 'c');
+            ->willReturnOnConsecutiveCalls('a', 'b', 'c');
 
         $this->assertEquals('a', $mock->doSomething());
         $this->assertEquals('b', $mock->doSomething());
@@ -368,12 +368,12 @@ final class MockObjectTest extends TestCase
     public function testStaticMethodCallback(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->onlyMethods(['doSomething'])
-                     ->getMock();
+            ->onlyMethods(['doSomething'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('doSomething')
-             ->will($this->returnCallback([MethodCallback::class, 'staticCallback']));
+            ->method('doSomething')
+            ->will($this->returnCallback([MethodCallback::class, 'staticCallback']));
 
         $this->assertEquals('pass', $mock->doSomething('foo', 'bar'));
     }
@@ -381,12 +381,12 @@ final class MockObjectTest extends TestCase
     public function testPublicMethodCallback(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->onlyMethods(['doSomething'])
-                     ->getMock();
+            ->onlyMethods(['doSomething'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('doSomething')
-             ->will($this->returnCallback([new MethodCallback, 'nonStaticCallback']));
+            ->method('doSomething')
+            ->will($this->returnCallback([new MethodCallback, 'nonStaticCallback']));
 
         $this->assertEquals('pass', $mock->doSomething('foo', 'bar'));
     }
@@ -394,10 +394,10 @@ final class MockObjectTest extends TestCase
     public function testMockClassOnlyGeneratedOnce(): void
     {
         $mock1 = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $mock2 = $this->getMockBuilder(AnInterface::class)
-                     ->getMock();
+            ->getMock();
 
         $this->assertEquals(get_class($mock1), get_class($mock2));
     }
@@ -405,23 +405,23 @@ final class MockObjectTest extends TestCase
     public function testMockClassDifferentForPartialMocks(): void
     {
         $mock1 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->getMock();
+            ->getMock();
 
         $mock2 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->onlyMethods(['doSomething'])
-                      ->getMock();
+            ->onlyMethods(['doSomething'])
+            ->getMock();
 
         $mock3 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->onlyMethods(['doSomething'])
-                      ->getMock();
+            ->onlyMethods(['doSomething'])
+            ->getMock();
 
         $mock4 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->onlyMethods(['doAnotherThing'])
-                      ->getMock();
+            ->onlyMethods(['doAnotherThing'])
+            ->getMock();
 
         $mock5 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->onlyMethods(['doAnotherThing'])
-                      ->getMock();
+            ->onlyMethods(['doAnotherThing'])
+            ->getMock();
 
         $this->assertNotEquals(get_class($mock1), get_class($mock2));
         $this->assertNotEquals(get_class($mock1), get_class($mock3));
@@ -436,23 +436,23 @@ final class MockObjectTest extends TestCase
     public function testMockClassStoreOverrulable(): void
     {
         $mock1 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->getMock();
+            ->getMock();
 
         $mock2 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->setMockClassName('MyMockClassNameForPartialMockTestClass1')
-                      ->getMock();
+            ->setMockClassName('MyMockClassNameForPartialMockTestClass1')
+            ->getMock();
 
         $mock3 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->getMock();
+            ->getMock();
 
         $mock4 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->onlyMethods(['doSomething'])
-                      ->setMockClassName('AnotherMockClassNameForPartialMockTestClass')
-                      ->getMock();
+            ->onlyMethods(['doSomething'])
+            ->setMockClassName('AnotherMockClassNameForPartialMockTestClass')
+            ->getMock();
 
         $mock5 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->setMockClassName('MyMockClassNameForPartialMockTestClass2')
-                      ->getMock();
+            ->setMockClassName('MyMockClassNameForPartialMockTestClass2')
+            ->getMock();
 
         $this->assertNotEquals(get_class($mock1), get_class($mock2));
         $this->assertEquals(get_class($mock1), get_class($mock3));
@@ -474,11 +474,11 @@ final class MockObjectTest extends TestCase
     public function testOriginalConstructorSettingConsidered(): void
     {
         $mock1 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->getMock();
+            ->getMock();
 
         $mock2 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->disableOriginalConstructor()
-                      ->getMock();
+            ->disableOriginalConstructor()
+            ->getMock();
 
         $this->assertTrue($mock1->constructorCalled);
         $this->assertFalse($mock2->constructorCalled);
@@ -487,11 +487,11 @@ final class MockObjectTest extends TestCase
     public function testOriginalCloneSettingConsidered(): void
     {
         $mock1 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->getMock();
+            ->getMock();
 
         $mock2 = $this->getMockBuilder(PartialMockTestClass::class)
-                      ->disableOriginalClone()
-                      ->getMock();
+            ->disableOriginalClone()
+            ->getMock();
 
         $this->assertNotEquals(get_class($mock1), get_class($mock2));
     }
@@ -502,10 +502,10 @@ final class MockObjectTest extends TestCase
     public function testGetMockForAbstractClass(): void
     {
         $mock = $this->getMockBuilder(AbstractMockTestClass::class)
-                     ->getMock();
+            ->getMock();
 
         $mock->expects($this->never())
-             ->method('doSomething');
+            ->method('doSomething');
     }
 
     /**
@@ -516,7 +516,7 @@ final class MockObjectTest extends TestCase
     public function testGetMockForTraversable($type): void
     {
         $mock = $this->getMockBuilder($type)
-                     ->getMock();
+            ->getMock();
 
         $this->assertInstanceOf(Traversable::class, $mock);
     }
@@ -529,7 +529,7 @@ final class MockObjectTest extends TestCase
         $mock = $this->getMockForTrait(AbstractTrait::class);
 
         $mock->expects($this->never())
-             ->method('doSomething');
+            ->method('doSomething');
 
         $parent = get_parent_class($mock);
         $traits = class_uses($parent, false);
@@ -540,7 +540,7 @@ final class MockObjectTest extends TestCase
     public function testClonedMockObjectShouldStillEqualTheOriginal(): void
     {
         $a = $this->getMockBuilder(stdClass::class)
-                  ->getMock();
+            ->getMock();
 
         $b = clone $a;
 
@@ -550,10 +550,10 @@ final class MockObjectTest extends TestCase
     public function testMockObjectsConstructedIndepentantlyShouldBeEqual(): void
     {
         $a = $this->getMockBuilder(stdClass::class)
-                  ->getMock();
+            ->getMock();
 
         $b = $this->getMockBuilder(stdClass::class)
-                  ->getMock();
+            ->getMock();
 
         $this->assertEquals($a, $b);
     }
@@ -561,10 +561,10 @@ final class MockObjectTest extends TestCase
     public function testMockObjectsConstructedIndepentantlyShouldNotBeTheSame(): void
     {
         $a = $this->getMockBuilder(stdClass::class)
-                  ->getMock();
+            ->getMock();
 
         $b = $this->getMockBuilder(stdClass::class)
-                  ->getMock();
+            ->getMock();
 
         $this->assertNotSame($a, $b);
     }
@@ -572,17 +572,17 @@ final class MockObjectTest extends TestCase
     public function testClonedMockObjectCanBeUsedInPlaceOfOriginalOne(): void
     {
         $x = $this->getMockBuilder(stdClass::class)
-                  ->getMock();
+            ->getMock();
 
         $y = clone $x;
 
         $mock = $this->getMockBuilder(stdClass::class)
-                     ->addMethods(['foo'])
-                     ->getMock();
+            ->addMethods(['foo'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('foo')
-             ->with($this->equalTo($x));
+            ->method('foo')
+            ->with($this->equalTo($x));
 
         $mock->foo($y);
     }
@@ -590,17 +590,17 @@ final class MockObjectTest extends TestCase
     public function testClonedMockObjectIsNotIdenticalToOriginalOne(): void
     {
         $x = $this->getMockBuilder(stdClass::class)
-                  ->getMock();
+            ->getMock();
 
         $y = clone $x;
 
         $mock = $this->getMockBuilder(stdClass::class)
-                     ->addMethods(['foo'])
-                     ->getMock();
+            ->addMethods(['foo'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('foo')
-             ->with($this->logicalNot($this->identicalTo($x)));
+            ->method('foo')
+            ->with($this->logicalNot($this->identicalTo($x)));
 
         $mock->foo($y);
     }
@@ -610,21 +610,21 @@ final class MockObjectTest extends TestCase
         $expectedObject = new stdClass;
 
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->onlyMethods(['doSomethingElse'])
-                     ->enableArgumentCloning()
-                     ->getMock();
+            ->onlyMethods(['doSomethingElse'])
+            ->enableArgumentCloning()
+            ->getMock();
 
         $actualArguments = [];
 
         $mock->method('doSomethingElse')
-             ->will(
-                 $this->returnCallback(
-                     static function () use (&$actualArguments): void
-                     {
-                         $actualArguments = func_get_args();
-                     }
-                 )
-             );
+            ->will(
+                $this->returnCallback(
+                    static function () use (&$actualArguments): void
+                    {
+                        $actualArguments = func_get_args();
+                    },
+                ),
+            );
 
         $mock->doSomethingElse($expectedObject);
 
@@ -638,21 +638,21 @@ final class MockObjectTest extends TestCase
         $expectedObject = new stdClass;
 
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->onlyMethods(['doSomethingElse'])
-                     ->disableArgumentCloning()
-                     ->getMock();
+            ->onlyMethods(['doSomethingElse'])
+            ->disableArgumentCloning()
+            ->getMock();
 
         $actualArguments = [];
 
         $mock->method('doSomethingElse')
-             ->will(
-                 $this->returnCallback(
-                     static function () use (&$actualArguments): void
-                     {
-                         $actualArguments = func_get_args();
-                     }
-                 )
-             );
+            ->will(
+                $this->returnCallback(
+                    static function () use (&$actualArguments): void
+                    {
+                        $actualArguments = func_get_args();
+                    },
+                ),
+            );
 
         $mock->doSomethingElse($expectedObject);
 
@@ -663,14 +663,14 @@ final class MockObjectTest extends TestCase
     public function testArgumentCloningOptionGeneratesUniqueMock(): void
     {
         $mockWithCloning = $this->getMockBuilder(SomeClass::class)
-                                ->onlyMethods(['doSomethingElse'])
-                                ->enableArgumentCloning()
-                                ->getMock();
+            ->onlyMethods(['doSomethingElse'])
+            ->enableArgumentCloning()
+            ->getMock();
 
         $mockWithoutCloning = $this->getMockBuilder(SomeClass::class)
-                                   ->onlyMethods(['doSomethingElse'])
-                                   ->disableArgumentCloning()
-                                   ->getMock();
+            ->onlyMethods(['doSomethingElse'])
+            ->disableArgumentCloning()
+            ->getMock();
 
         $this->assertNotEquals($mockWithCloning, $mockWithoutCloning);
     }
@@ -678,11 +678,11 @@ final class MockObjectTest extends TestCase
     public function testVerificationOfMethodNameFailsWithoutParameters(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->addMethods(['right', 'wrong'])
-                     ->getMock();
+            ->addMethods(['right', 'wrong'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('right');
+            ->method('right');
 
         $mock->wrong();
 
@@ -693,7 +693,7 @@ final class MockObjectTest extends TestCase
             $this->assertSame(
                 "Expectation failed for method name is \"right\" when invoked 1 time(s).\n" .
                 'Method was expected to be called 1 times, actually called 0 times.' . "\n",
-                $e->getMessage()
+                $e->getMessage(),
             );
         }
 
@@ -703,11 +703,11 @@ final class MockObjectTest extends TestCase
     public function testVerificationOfMethodNameFailsWithParameters(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->addMethods(['right', 'wrong'])
-                     ->getMock();
+            ->addMethods(['right', 'wrong'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('right');
+            ->method('right');
 
         $mock->wrong();
 
@@ -718,7 +718,7 @@ final class MockObjectTest extends TestCase
             $this->assertSame(
                 "Expectation failed for method name is \"right\" when invoked 1 time(s).\n" .
                 'Method was expected to be called 1 times, actually called 0 times.' . "\n",
-                $e->getMessage()
+                $e->getMessage(),
             );
         }
 
@@ -728,12 +728,12 @@ final class MockObjectTest extends TestCase
     public function testVerificationOfMethodNameFailsWithWrongParameters(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->addMethods(['right', 'wrong'])
-                     ->getMock();
+            ->addMethods(['right', 'wrong'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('right')
-             ->with(['first', 'second']);
+            ->method('right')
+            ->with(['first', 'second']);
 
         try {
             $mock->right(['second']);
@@ -746,9 +746,9 @@ Parameter 0 for invocation %s::right(Array (...)) does not match expected value.
 Failed asserting that two arrays are equal.
 EOF
                     ,
-                    SomeClass::class
+                    SomeClass::class,
                 ),
-                $e->getMessage()
+                $e->getMessage(),
             );
         }
 
@@ -775,9 +775,9 @@ Failed asserting that two arrays are equal.
 
 EOF
                     ,
-                    SomeClass::class
+                    SomeClass::class,
                 ),
-                $e->getMessage()
+                $e->getMessage(),
             );
         }
 
@@ -787,12 +787,12 @@ EOF
     public function testVerificationOfNeverFailsWithEmptyParameters(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->addMethods(['right', 'wrong'])
-                     ->getMock();
+            ->addMethods(['right', 'wrong'])
+            ->getMock();
 
         $mock->expects($this->never())
-             ->method('right')
-             ->with();
+            ->method('right')
+            ->with();
 
         try {
             $mock->right();
@@ -801,9 +801,9 @@ EOF
             $this->assertSame(
                 sprintf(
                     '%s::right() was not expected to be called.',
-                    SomeClass::class
+                    SomeClass::class,
                 ),
-                $e->getMessage()
+                $e->getMessage(),
             );
         }
 
@@ -813,12 +813,12 @@ EOF
     public function testVerificationOfNeverFailsWithAnyParameters(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->addMethods(['right', 'wrong'])
-                     ->getMock();
+            ->addMethods(['right', 'wrong'])
+            ->getMock();
 
         $mock->expects($this->never())
-             ->method('right')
-             ->withAnyParameters();
+            ->method('right')
+            ->withAnyParameters();
 
         try {
             $mock->right();
@@ -827,9 +827,9 @@ EOF
             $this->assertSame(
                 sprintf(
                     '%s::right() was not expected to be called.',
-                    SomeClass::class
+                    SomeClass::class,
                 ),
-                $e->getMessage()
+                $e->getMessage(),
             );
         }
 
@@ -839,12 +839,12 @@ EOF
     public function testWithAnythingInsteadOfWithAnyParameters(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->addMethods(['right', 'wrong'])
-                     ->getMock();
+            ->addMethods(['right', 'wrong'])
+            ->getMock();
 
         $mock->expects($this->once())
-             ->method('right')
-             ->with($this->anything());
+            ->method('right')
+            ->with($this->anything());
 
         try {
             $mock->right();
@@ -858,9 +858,9 @@ Parameter count for invocation %s::right() is too low.
 To allow 0 or more parameters with any value, omit ->with() or use ->withAnyParameters() instead.
 EOF
                     ,
-                    SomeClass::class
+                    SomeClass::class,
                 ),
-                $e->getMessage()
+                $e->getMessage(),
             );
         }
 
@@ -873,10 +873,10 @@ EOF
     public function testMockArgumentsPassedByReference(): void
     {
         $foo = $this->getMockBuilder(MethodCallbackByReference::class)
-                    ->onlyMethods(['bar'])
-                    ->disableOriginalConstructor()
-                    ->disableArgumentCloning()
-                    ->getMock();
+            ->onlyMethods(['bar'])
+            ->disableOriginalConstructor()
+            ->disableArgumentCloning()
+            ->getMock();
 
         $foo->method('bar')
             ->will($this->returnCallback([$foo, 'callback']));
@@ -894,16 +894,16 @@ EOF
     public function testMockArgumentsPassedByReference2(): void
     {
         $foo = $this->getMockBuilder(MethodCallbackByReference::class)
-                    ->disableOriginalConstructor()
-                    ->disableArgumentCloning()
-                    ->getMock();
+            ->disableOriginalConstructor()
+            ->disableArgumentCloning()
+            ->getMock();
 
         $foo->method('bar')
             ->will($this->returnCallback(
                 static function (&$a, &$b, $c): void
                 {
                     $b = 1;
-                }
+                },
             ));
 
         $a = $b = $c = 0;
@@ -919,10 +919,10 @@ EOF
     public function testMockArgumentsPassedByReference3(): void
     {
         $foo = $this->getMockBuilder(MethodCallbackByReference::class)
-                    ->onlyMethods(['bar'])
-                    ->disableOriginalConstructor()
-                    ->disableArgumentCloning()
-                    ->getMock();
+            ->onlyMethods(['bar'])
+            ->disableOriginalConstructor()
+            ->disableArgumentCloning()
+            ->getMock();
 
         $a = new stdClass;
         $b = $c = 0;
@@ -940,10 +940,10 @@ EOF
     public function testMockArgumentsPassedByReference4(): void
     {
         $foo = $this->getMockBuilder(MethodCallbackByReference::class)
-                    ->onlyMethods(['bar'])
-                    ->disableOriginalConstructor()
-                    ->disableArgumentCloning()
-                    ->getMock();
+            ->onlyMethods(['bar'])
+            ->disableOriginalConstructor()
+            ->disableArgumentCloning()
+            ->getMock();
 
         $a = new stdClass;
         $b = $c = 0;
@@ -964,7 +964,7 @@ EOF
 
         $this->assertStringStartsWith(
             'Mock_WsdlMock_',
-            get_class($mock)
+            get_class($mock),
         );
     }
 
@@ -977,7 +977,7 @@ EOF
 
         $this->assertStringStartsWith(
             'Mock_WsdlMock_',
-            get_class($mock)
+            get_class($mock),
         );
     }
 
@@ -1016,7 +1016,7 @@ EOF
     {
         $this->assertInstanceOf(
             InterfaceWithStaticMethod::class,
-            $this->getMockBuilder(InterfaceWithStaticMethod::class)->getMock()
+            $this->getMockBuilder(InterfaceWithStaticMethod::class)->getMock(),
         );
     }
 
@@ -1041,8 +1041,8 @@ EOF
         $this->assertInstanceOf(
             ClassThatImplementsSerializable::class,
             $this->getMockBuilder(ClassThatImplementsSerializable::class)
-                 ->disableOriginalConstructor()
-                 ->getMock()
+                ->disableOriginalConstructor()
+                ->getMock(),
         );
     }
 
@@ -1050,7 +1050,7 @@ EOF
     {
         $this->assertInstanceOf(
             ClassWithSelfTypeHint::class,
-            $this->getMockBuilder(ClassWithSelfTypeHint::class)->getMock()
+            $this->getMockBuilder(ClassWithSelfTypeHint::class)->getMock(),
         );
     }
 
@@ -1114,13 +1114,13 @@ EOF
     public function testDisableAutomaticReturnValueGeneration(): void
     {
         $mock = $this->getMockBuilder(SomeClass::class)
-                     ->disableAutoReturnValueGeneration()
-                     ->getMock();
+            ->disableAutoReturnValueGeneration()
+            ->getMock();
 
         $this->expectException(ReturnValueNotConfiguredException::class);
         $this->expectExceptionMessage(sprintf(
             'Return value inference disabled and no expectation set up for %s::doSomethingElse()',
-            SomeClass::class
+            SomeClass::class,
         ));
 
         $mock->doSomethingElse(1);
@@ -1142,9 +1142,9 @@ EOF
             $this->assertSame(
                 sprintf(
                     'Return value inference disabled and no expectation set up for %s::__toString()',
-                    StringableClass::class
+                    StringableClass::class,
                 ),
-                $e->getMessage()
+                $e->getMessage(),
             );
         }
 
